@@ -42,11 +42,7 @@ public class Month implements Comparable<Month>, java.io.Serializable {
 	 * コンストラクタ。今月の年月が設定されます。
 	 */
 	public Month() {
-		try {
-			AJD	now = new AJD();
-			init( now.getYear(), now.getMonth() );
-		}
-		catch( AJDException e ){}
+		this( new AJD() );
 	}
 
 	/**
@@ -58,6 +54,17 @@ public class Month implements Comparable<Month>, java.io.Serializable {
 		init( yyyy, mm );
 	}
 
+	/**
+	 * コンストラクタ。引数の年月と同じ月を設定します。
+	 * @param ajd 年月。
+	 */
+	public Month( AJD ajd ) {
+		try {
+			init( ajd.getYear(), ajd.getMonth() );
+		}
+		catch( AJDException e ){}
+	}
+
 	/**
 	 * 年の取得。
 	 * @return 年。負数は紀元前です。0は返しません。
@@ -116,28 +123,45 @@ public class Month implements Comparable<Month>, java.io.Serializable {
 
 	/**
 	 * 閏年であるか？1582年を境に閏年判定が変わります。
+	 * @param yyyy 年。
 	 * @return true:閏年、false:平年。
 	 */
-	public boolean isLeapYear() {
-		if ( ( y % 4 ) == 0 ) {
-			if ( ( y % 100 ) == 0 && y > 1582 ) {
-				if ( ( y % 400 ) == 0 )	return true;
+	public static boolean isLeapYear( int yyyy ) {
+		if ( ( yyyy % 4 ) == 0 ) {
+			if ( ( yyyy % 100 ) == 0 && yyyy > 1582 ) {
+				if ( ( yyyy % 400 ) == 0 )	return true;
 			}
 			else	return true;
 		}
 		return false;
 	}
+	/**
+	 * 閏年であるか？1582年を境に閏年判定が変わります。
+	 * @return true:閏年、false:平年。
+	 */
+	public boolean isLeapYear() {
+		return isLeapYear( y );
+	}
 
+	/**
+	 * 月の最終日取得。
+	 * @param yyyy 年。
+	 * @param mm 日。
+	 * @return 1月なら31。2月は閏年判定を行います。
+	 */
+	public static int getLastDay( int yyyy, int mm ) {
+		if ( mm == 2 ) {
+			if ( isLeapYear( yyyy ) )	return days[1] + 1;
+			return days[1];
+		}
+		return days[mm - 1];
+	}
 	/**
 	 * 月の最終日取得。
 	 * @return 1月なら31。2月は閏年判定を行います。
 	 */
 	public int getLastDay() {
-		if ( m == 2 ) {
-			if ( isLeapYear() )	return days[1] + 1;
-			return days[1];
-		}
-		return days[m - 1];
+		return getLastDay( y, m );
 	}
 
 	private transient AJD[]	ajd = null;
