@@ -6,6 +6,9 @@
  */
 package ajd4jp;
 
+import ajd4jp.util.*;
+
+
 /**
  * 曜日を表します。
  */
@@ -55,7 +58,7 @@ public enum Week implements OffProvider.Off {
 	 * @return 曜日。
 	 */
 	public static Week get( Day date ) {
-		return values()[(int)(AJD.cut( date.getAJD() ) + 2) % 7];
+		return values()[(int)(Calc.cut( date.getAJD() ) + 2) % 7];
 	}
 
 	int get() { return no; }
